@@ -12,7 +12,7 @@
 ** This file contains C code routines that are called by the parser
 ** to handle INSERT statements in SQLite.
 **
-** $Id: insert.c,v 1.1.1.1 2002/02/18 17:38:58 matt Exp $
+** $Id: insert.c,v 1.2 2002/02/27 19:25:22 matt Exp $
 */
 #include "sqliteInt.h"
 
@@ -100,10 +100,20 @@ void sqliteInsert(
     assert( pSelect->pEList );
     nColumn = pSelect->pEList->nExpr;
   }else{
+    IdList dummy;
     assert( pList!=0 );
     srcTab = -1;
     assert( pList );
     nColumn = pList->nExpr;
+    for(i=0; i<nColumn; i++){
+      sqliteExprResolveInSelect(pParse, pList->a[i].pExpr);
+    }
+    dummy.nId = 0;
+    for(i=0; i<nColumn; i++){
+      if( sqliteExprResolveIds(pParse, &dummy, 0, pList->a[i].pExpr) ){
+        goto insert_cleanup;
+      }
+    }
   }
 
   /* Make sure the number of columns in the source data matches the number
